@@ -18,17 +18,16 @@
  ***************************************************************************/
 
 #include "actioncollection.h"
-#include "action.h"
 #include "manager.h"
 #include "kross_debug.h"
 
-#include <QtCore/QHash>
-#include <QtCore/QStringList>
-#include <QtCore/QPointer>
-#include <QtCore/QIODevice>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtXml/QDomAttr>
+#include <QHash>
+#include <QStringList>
+#include <QPointer>
+#include <QIODevice>
+#include <QFile>
+#include <QFileInfo>
+#include <QDomAttr>
 
 #include <klocalizedstring.h>
 
@@ -347,8 +346,8 @@ bool ActionCollection::readXml(const QDomElement &element, const QStringList &se
                 c = new ActionCollection(name, this);
             }
 
-            c->setText(text.isEmpty() ? name : i18n(text.constData()));
-            c->setDescription(description.isEmpty() ? c->text() : i18n(description.constData()));
+            c->setText(text.isEmpty() ? name : i18nd(KLocalizedString::applicationDomain().constData(), text.constData()));
+            c->setDescription(description.isEmpty() ? c->text() : i18nd(KLocalizedString::applicationDomain().constData(), description.constData()));
             c->setIconName(iconname);
 
             if (! enabled) {
@@ -521,3 +520,4 @@ bool ActionCollection::writeXml(QIODevice *device, int indent, const QStringList
     return device->write(document.toByteArray(indent)) != -1;
 }
 
+#include "moc_actioncollection.cpp"
